@@ -59,6 +59,11 @@ class Resource(object):
     #: Dictionary with the path parameters. Set by the constructor.
     path_params = None
 
+    #: String with the current path. Same as request.path except the extension
+    #: is removed. So instead of `/movies.json' it is just `/movies'. Set by
+    #: the constructor.
+    request_path = None
+
     #: Reference to the application. Set by the constructor.
     application = None
 
@@ -87,6 +92,13 @@ class Resource(object):
         self.response = response
         self.path_params = path_params
         self.application = application
+        self.request_path = ''
+        if request:
+            self.request_path = request.path
+            if path_params and path_params.get('_extension'):
+                ext = path_params['_extension']
+                if self.request_path.endswith(ext):
+                    self.request_path = self.request_path[0:-len(ext)]
 
     def OPTIONS(self):
         """Default implementation of the OPTIONS verb. Outputs a list of
@@ -364,6 +376,7 @@ class Resource(object):
                     value = source[param]
                     break
             self.validate_param(method, param, value)
+            value = self.convert_param(method, param, value)
             params.append(value)
         return method(*params)
 
@@ -389,14 +402,40 @@ class Resource(object):
         rules = self._get_validation(method, param)
         if not rules:
             return
-        if value is None or len(str(value)) == 0:
+        if value is None or (isinstance(value, basestring) and len(value) == 0):
             raise ValidationException(
                 "Value for {0} must not be empty.".format(param))
-        elif 're' in rules and rules['re']:
+        elif rules.get('re'):
             if not re.search('^' + rules['re'] + '$', value):
                 raise ValidationException(
                     "{0} value {1} does not validate.".format(param, value))
 
+    def convert_param(self, method, param, value):
+        """Converts the parameter using the function 'convert' function of the
+        validation rules. Same parameters as the `validate_param` method, so
+        it might have just been added there. But lumping together the two
+        functionalities would make overwriting harder.
+
+        :param method: A function to get the validation information from (done
+                       using :func:`_get_validation`).
+        :type method: Python function
+        :param param: Name of the parameter to validate the value for.
+        :type param: str
+        :param value: Value passed in for the given parameter.
+        :type value: Any valid Python value
+
+        :raises: :class:`webob.exceptions.ValidationException` if the value is
+                 invalid for the given method and parameter.
+        """
+        rules = self._get_validation(method, param)
+        if not rules or not rules.get('convert'):
+            return value
+        try:
+            return rules['convert'](value)
+        except ValueError:
+            raise ValidationException(
+                "{0} value {1} does not validate.".format(param, value))
+
     def _get_validation(self, method, param):
         """Return the correct validations dictionary for this parameter.
         First checks the method itself and then its class. If no validation is
